@@ -1,24 +1,32 @@
-#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>#
-#  Chart::Lines               #
-#                             #
-#  written by david bonner    #
-#  dbonner@cs.bu.edu          #
-#                             #
-#  maintained by peter clark  #
-#  ninjaz@webexpress.com      #
-#                             #
-#  theft is treason, citizen  #
-#<<<<<<<<<<<<<<<<<<<<<<<<<<<<<#
+#====================================================================
+#  Chart::Lines
+#                                
+#  written by david bonner        
+#  dbonner@cs.bu.edu              
+#
+#  maintained by the Chart Group
+#  Chart@wettzell.ifag.de
+#
+#---------------------------------------------------------------------
+# History:
+#----------
+# $RCSfile: Lines.pm,v $ $Revision: 1.4 $ $Date: 2003/02/14 14:08:24 $
+# $Author: dassing $
+# $Log: Lines.pm,v $
+# Revision 1.4  2003/02/14 14:08:24  dassing
+# First setup to cvs
+#
+#====================================================================
 
 package Chart::Lines;
 
-use Chart::Base;
+use Chart::Base '2.4.1';
 use GD;
 use Carp;
 use strict;
 
 @Chart::Lines::ISA = qw(Chart::Base);
-$Chart::Lines::VERSION = '2.0';
+$Chart::Lines::VERSION = '2.4.1';
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
@@ -50,7 +58,7 @@ sub _draw_data {
   # as the mapping constant
   $width = $self->{'curr_x_max'} - $self->{'curr_x_min'};
   $height = $self->{'curr_y_max'} - $self->{'curr_y_min'};
-  $delta = $width / $self->{'num_datapoints'};
+  $delta = $width / ($self->{'num_datapoints'} > 0 ? $self->{'num_datapoints'} : 1);
   $map = $height / ($self->{'max_val'} - $self->{'min_val'});
 
   #for a xy-plot, use this delta and maybe an offset for the zero-axes
@@ -97,7 +105,7 @@ sub _draw_data {
     $color = $self->_color_role_to_index('dataset'.($i-1));
     $brush = $self->_prepare_brush ($color);
     $self->{'gd_obj'}->setBrush ($brush);
-
+    
     # draw every line for this dataset
     for $j (1..$self->{'num_datapoints'}) {
       # don't try to draw anything if there's no data
@@ -113,10 +121,32 @@ sub _draw_data {
 	$y2 = $y1 - (($data->[$i][$j-1] - $mod) * $map);
 	$y3 = $y1 - (($data->[$i][$j] - $mod) * $map);
 
-        #now draw the line
-        $self->{'gd_obj'}->line($x2, $y2, $x3, $y3, gdBrushed);
-     #   print $x2,  " ";
-        #set the flags, if the lines are out of the borders of the chart
+        # now draw the line
+        # ----------------
+        # stepline option added by G.ST. 2005/02
+        #----------------
+        if ($self->{'stepline'} =~ /^true$/i ) 
+        {
+           if ($self->{'stepline_mode'} =~ /^begin$/i ) 
+           {
+              $self->{'gd_obj'}->line($x2, $y2, $x3, $y2, gdBrushed);
+              $self->{'gd_obj'}->line($x3, $y2, $x3, $y3, gdBrushed);
+           }
+           else 
+           {
+              $self->{'gd_obj'}->line($x2, $y2, $x2, $y3, gdBrushed);
+              $self->{'gd_obj'}->line($x2, $y3, $x3, $y3, gdBrushed);
+           }
+        }
+        # -----------------------------------
+        # end stepline option
+        #------------------------------------
+        else
+        {
+            $self->{'gd_obj'}->line($x2, $y2, $x3, $y3, gdBrushed);
+        }
+        
+        # set the flags, if the lines are out of the borders of the chart
         if ( ($data->[$i][$j] > $self->{'max_val'}) || ($data->[$i][$j-1] > $self->{'max_val'}) ) {
            $repair_top_flag = 1;
         }
@@ -155,7 +185,7 @@ sub _draw_data {
   #repair the chart, if the lines are out of the borders of the chart
   if ($repair_top_flag) {
    #overwrite the ugly mistakes
-   $self->{'gd_obj'}->filledRectangle ($self->{'curr_x_min'}, 0,
+   $self->{'gd_obj'}->filledRectangle ($self->{'curr_x_min'}-($self->{'brush_size'}/2), 0,
 				$self->{'curr_x_max'}, $self->{'curr_y_min'}-1,
 				$self->_color_role_to_index('background'));
 
@@ -197,7 +227,7 @@ sub _draw_data {
   if ($repair_bottom_flag) {
 
    #overwrite the ugly mistakes
-   $self->{'gd_obj'}->filledRectangle ($self->{'curr_x_min'}, $self->{'curr_y_max'}+1,
+   $self->{'gd_obj'}->filledRectangle ($self->{'curr_x_min'}-($self->{'brush_size'}/2), $self->{'curr_y_max'}+1,
 				$self->{'curr_x_max'}, $abs_y_max,
 				$self->_color_role_to_index('background'));
     #save the actual x and y values
